@@ -10,63 +10,75 @@
 #   A vector of length draws$nsamples containing samples
 #   from the posterior predictive distribution
 predict_gaussian <- function(i, draws, ...) {
-  sigma <- get_sigma(draws$sigma, data = draws$data, method = "predict", i = i)
-  args <- list(mean = ilink(get_eta(i, draws), draws$f$link), sd = sigma)
-  rng_continuous(nrng = draws$nsamples, dist = "norm",
-                 args = args, data = draws$data)
+  args <- list(mean = ilink(get_eta(draws, i), draws$f$link), 
+               sd = get_sigma(draws$sigma, data = draws$data, i = i))
+  rng_continuous(nrng = draws$nsamples, dist = "norm", args = args, 
+                 lb = draws$data$lb[i], ub = draws$data$ub[i])
 }
 
 predict_student <- function(i, draws, ...) {
-  sigma <- get_sigma(draws$sigma, data = draws$data, method = "predict", i = i)
-  args <- list(df = draws$nu, mu = ilink(get_eta(i, draws), draws$f$link), sigma = sigma)
-  rng_continuous(nrng = draws$nsamples, dist = "student",
-                 args = args, data = draws$data)
+  args <- list(df = get_auxpar(draws$nu, i = i), 
+               mu = ilink(get_eta(draws, i), draws$f$link), 
+               sigma = get_sigma(draws$sigma, data = draws$data, i = i))
+  rng_continuous(nrng = draws$nsamples, dist = "student", args = args, 
+                 lb = draws$data$lb[i], ub = draws$data$ub[i])
 }
 
 predict_cauchy <- function(i, draws, ...) {
-  sigma <- get_sigma(draws$sigma, data = draws$data, method = "predict", i = i)
-  args <- list(df = 1, mu = ilink(get_eta(i, draws), draws$f$link), sigma = sigma)
-  rng_continuous(nrng = draws$nsamples, dist = "student",
-                 args = args, data = draws$data)
+  args <- list(df = 1, mu = ilink(get_eta(draws, i), draws$f$link), 
+               sigma = get_sigma(draws$sigma, data = draws$data, i = i))
+  rng_continuous(nrng = draws$nsamples, dist = "student", args = args,
+                 lb = draws$data$lb[i], ub = draws$data$ub[i])
 }
 
 predict_lognormal <- function(i, draws, ...) {
-  sigma <- get_sigma(draws$sigma, data = draws$data, method = "predict", i = i)
-  args <- list(meanlog = ilink(get_eta(i, draws), draws$f$link), sdlog = sigma)
-  rng_continuous(nrng = draws$nsamples, dist = "lnorm",
-                 args = args, data = draws$data)
+  args <- list(meanlog = ilink(get_eta(draws, i), draws$f$link), 
+               sdlog = get_sigma(draws$sigma, data = draws$data, i = i))
+  rng_continuous(nrng = draws$nsamples, dist = "lnorm", args = args, 
+                 lb = draws$data$lb[i], ub = draws$data$ub[i])
 }
 
-predict_gaussian_multi <- function(i, draws, ...) {
+predict_gaussian_mv <- function(i, draws, ...) {
   # currently no truncation available
-  obs <- seq(i, draws$data$N, draws$data$N_trait)
-  eta <- get_eta(obs, draws)
+  if (!is.null(draws$data$N_trait)) {
+    obs <- seq(i, draws$data$N, draws$data$N_trait)
+    mu <- ilink(get_eta(draws, obs), draws$f$link)
+  } else {
+    mu <- ilink(get_eta(draws, i), draws$f$link)[, 1, ]
+  }
   .fun <- function(s) {
-    rmulti_normal(1, Sigma = draws$Sigma[s, , ],
-                  mu = ilink(eta[s, ], draws$f$link))
+    rmulti_normal(1, mu = mu[s, ], Sigma = draws$Sigma[s, , ])
   }
   do.call(rbind, lapply(1:draws$nsamples, .fun))
 }
 
-predict_student_multi <- function(i, draws, ...) {
+predict_student_mv <- function(i, draws, ...) {
   # currently no truncation available
-  obs <- seq(i, draws$data$N, draws$data$N_trait)
-  eta <- get_eta(obs, draws)
+  if (!is.null(draws$data$N_trait)) {
+    obs <- seq(i, draws$data$N, draws$data$N_trait)
+    mu <- ilink(get_eta(draws, obs), draws$f$link)
+  } else {
+    mu <- ilink(get_eta(draws, i), draws$f$link)[, 1, ]
+  }
+  nu <- get_auxpar(draws$nu, i = i)
   .fun <- function(s) {
-    rmulti_student(1, df = draws$nu[s, ], 
-                  mu = ilink(eta[s, ], draws$f$link),
-                  Sigma = draws$Sigma[s, , ])
+    rmulti_student(1, df = nu[s, ], mu = mu[s, ], 
+                   Sigma = draws$Sigma[s, , ])
   }
   do.call(rbind, lapply(1:draws$nsamples, .fun))
 }
 
-predict_cauchy_multi <- function(i, draws, ...) {
+predict_cauchy_mv <- function(i, draws, ...) {
   # currently no truncation available
-  obs <- seq(i, draws$data$N, draws$data$N_trait)
-  eta <- get_eta(obs, draws)
+  if (!is.null(draws$data$N_trait)) {
+    obs <- seq(i, draws$data$N, draws$data$N_trait)
+    mu <- ilink(get_eta(draws, obs), draws$f$link)
+  } else {
+    mu <- ilink(get_eta(draws, i), draws$f$link)[, 1, ]
+  }
   .fun <- function(s) {
-    rmulti_student(1, df = 1, mu = ilink(eta[s, ], draws$f$link),
-                  Sigma = draws$Sigma[s, , ])
+    rmulti_student(1, df = 1, mu = mu[s, ],
+                   Sigma = draws$Sigma[s, , ])
   }
   do.call(rbind, lapply(1:draws$nsamples, .fun))
 }
@@ -74,9 +86,9 @@ predict_cauchy_multi <- function(i, draws, ...) {
 predict_gaussian_cov <- function(i, draws, ...) {
   # currently, only ARMA1 processes are implemented
   obs <- with(draws$data, begin_tg[i]:(begin_tg[i] + nobs_tg[i] - 1))
-  eta <- get_eta(obs, draws)
-  args <- list(sigma = draws$sigma, se2 = draws$data$se2[obs], 
-               nrows = length(obs))
+  mu <- ilink(get_eta(draws, obs), draws$f$link)
+  args <- list(sigma = get_sigma(draws$sigma, data = draws$data, i = i), 
+               se2 = draws$data$se2[obs], nrows = length(obs))
   if (!is.null(draws$ar) && is.null(draws$ma)) {
     # AR1 process
     args$ar <- draws$ar
@@ -94,8 +106,7 @@ predict_gaussian_cov <- function(i, draws, ...) {
     Sigma <- do.call(get_cov_matrix_ident, args)
   }
   .fun <- function(s) {
-    rmulti_normal(1, mu = ilink(eta[s, ], draws$f$link), 
-                  Sigma = Sigma[s, , ])
+    rmulti_normal(1, mu = mu[s, ], Sigma = Sigma[s, , ])
   }
   do.call(rbind, lapply(1:draws$nsamples, .fun))
 }
@@ -103,9 +114,9 @@ predict_gaussian_cov <- function(i, draws, ...) {
 predict_student_cov <- function(i, draws, ...) {
   # currently, only ARMA1 processes are implemented
   obs <- with(draws$data, begin_tg[i]:(begin_tg[i] + nobs_tg[i] - 1))
-  eta <- get_eta(obs, draws)
-  args <- list(sigma = draws$sigma, se2 = draws$data$se2[obs], 
-               nrows = length(obs))
+  mu <- ilink(get_eta(draws, obs), draws$f$link)
+  args <- list(sigma = get_sigma(draws$sigma, data = draws$data, i = i), 
+               se2 = draws$data$se2[obs], nrows = length(obs))
   if (!is.null(draws$ar) && is.null(draws$ma)) {
     # AR1 process
     args$ar <- draws$ar
@@ -122,9 +133,9 @@ predict_student_cov <- function(i, draws, ...) {
     # identity matrix
     Sigma <- do.call(get_cov_matrix_ident, args)
   }
+  nu <- get_auxpar(draws$nu, i = i)
   .fun <- function(s) {
-    rmulti_student(1, df = draws$nu[s, ], 
-                   mu = ilink(eta[s, ], draws$f$link), 
+    rmulti_student(1, df = nu[s, ], mu = mu[s, ], 
                    Sigma = Sigma[s, , ])
   }
   do.call(rbind, lapply(1:draws$nsamples, .fun))
@@ -137,20 +148,19 @@ predict_cauchy_cov <- function(i, draws, ...) {
 
 predict_gaussian_fixed <- function(i, draws, ...) {
   stopifnot(i == 1)
-  eta <- get_eta(1:nrow(draws$data$V), draws)
+  mu <- ilink(get_eta(draws, 1:nrow(draws$data$V)), draws$f$link)
   .fun <- function(s) {
-    rmulti_normal(1, mu = ilink(eta[s, ], draws$f$link), 
-                  Sigma = draws$data$V)
+    rmulti_normal(1, mu = mu[s, ], Sigma = draws$data$V)
   }
   do.call(rbind, lapply(1:draws$nsamples, .fun))
 }
 
 predict_student_fixed <- function(i, draws, ...) {
   stopifnot(i == 1)
-  eta <- get_eta(1:nrow(draws$data$V), draws)
+  mu <- ilink(get_eta(draws, 1:nrow(draws$data$V)), draws$f$link)
+  nu <- get_auxpar(draws$nu, 1:nrow(draws$data$V))
   .fun <- function(s) {
-    rmulti_student(1, df = draws$nu[s, ], Sigma = draws$data$V,
-                   mu = ilink(eta[s, ], draws$f$link))
+    rmulti_student(1, df = nu[s, ], mu = mu[s, ], Sigma = draws$data$V)
   }
   do.call(rbind, lapply(1:draws$nsamples, .fun))
 }
@@ -164,80 +174,88 @@ predict_cauchy_fixed <- function(i, draws, ...) {
 predict_binomial <- function(i, draws, ntrys = 5, ...) {
   trials <- ifelse(length(draws$data$max_obs) > 1, 
                    draws$data$max_obs[i], draws$data$max_obs) 
-  args <- list(size = trials, prob = ilink(get_eta(i, draws), draws$f$link))
-  rng_discrete(nrng = draws$nsamples, dist = "binom",
-               args = args, data = draws$data, ntrys = ntrys)
+  args <- list(size = trials, prob = ilink(get_eta(draws, i), draws$f$link))
+  rng_discrete(nrng = draws$nsamples, dist = "binom", args = args, 
+               lb = draws$data$lb[i], ub = draws$data$ub[i], 
+               ntrys = ntrys)
 }
 
 predict_bernoulli <- function(i, draws, ...) {
   # truncation not useful
-  if (!is.null(draws$data$N_trait)) {  # 2PL model
-    eta <- get_eta(i, draws) * exp(get_eta(i + draws$data$N_trait, draws))
-  } else {
-    eta <- get_eta(i, draws)
-  }
+  eta <- get_eta(draws, i)
   rbinom(length(eta), size = 1, prob = ilink(eta, draws$f$link))
 }
 
 predict_poisson <- function(i, draws, ntrys = 5, ...) {
-  args <- list(lambda = ilink(get_eta(i, draws), draws$f$link))
-  rng_discrete(nrng = draws$nsamples, dist = "pois",
-               args = args, data = draws$data, ntrys = ntrys)
+  args <- list(lambda = ilink(get_eta(draws, i), draws$f$link))
+  rng_discrete(nrng = draws$nsamples, dist = "pois", args = args, 
+               lb = draws$data$lb[i], ub = draws$data$ub[i],
+               ntrys = ntrys)
 }
 
 predict_negbinomial <- function(i, draws, ntrys = 5, ...) {
-  shape <- get_shape(draws$shape, data = draws$data, method = "predict", i = i)
-  args <- list(mu = ilink(get_eta(i, draws), draws$f$link), size = shape)
-  rng_discrete(nrng = draws$nsamples, dist = "nbinom",
-               args = args, data = draws$data, ntrys = ntrys)
+  args <- list(mu = ilink(get_eta(draws, i), draws$f$link), 
+               size = get_shape(draws$shape, data = draws$data, i = i))
+  rng_discrete(nrng = draws$nsamples, dist = "nbinom", args = args, 
+               lb = draws$data$lb[i], ub = draws$data$ub[i],
+               ntrys = ntrys)
 }
 
 predict_geometric <- function(i, draws, ntrys = 5, ...) {
-  args <- list(mu = ilink(get_eta(i, draws), draws$f$link), size = 1)
-  rng_discrete(nrng = draws$nsamples, dist = "nbinom",
-               args = args, data = draws$data, ntrys = ntrys)
+  args <- list(mu = ilink(get_eta(draws, i), draws$f$link), size = 1)
+  rng_discrete(nrng = draws$nsamples, dist = "nbinom", args = args, 
+               lb = draws$data$lb[i], ub = draws$data$ub[i], 
+               ntrys = ntrys)
 }
 
 predict_exponential <- function(i, draws, ...) {
-  args <- list(rate = 1 / ilink(get_eta(i, draws), draws$f$link))
-  rng_continuous(nrng = draws$nsamples, dist = "exp",
-                 args = args, data = draws$data)
+  args <- list(rate = 1 / ilink(get_eta(draws, i), draws$f$link))
+  rng_continuous(nrng = draws$nsamples, dist = "exp", args = args, 
+                 lb = draws$data$lb[i], ub = draws$data$ub[i])
 }
 
 predict_gamma <- function(i, draws, ...) {
-  shape <- get_shape(draws$shape, data = draws$data, method = "predict", i = i)
+  shape <- get_shape(draws$shape, data = draws$data, i = i)
   args <- list(shape = shape, 
-               scale = ilink(get_eta(i, draws), draws$f$link) / shape)
-  rng_continuous(nrng = draws$nsamples, dist = "gamma",
-                 args = args, data = draws$data)
+               scale = ilink(get_eta(draws, i), draws$f$link) / shape)
+  rng_continuous(nrng = draws$nsamples, dist = "gamma", args = args, 
+                 lb = draws$data$lb[i], ub = draws$data$ub[i])
 }
 
 predict_weibull <- function(i, draws, ...) {
-  shape <- get_shape(draws$shape, data = draws$data, method = "predict", i = i)
+  shape <- get_shape(draws$shape, data = draws$data, i = i)
   args <- list(shape = shape, 
-               scale = ilink(get_eta(i, draws) / shape, draws$f$link))
-  rng_continuous(nrng = draws$nsamples, dist = "weibull",
-                 args = args, data = draws$data)
+               scale = ilink(get_eta(draws, i) / shape, draws$f$link))
+  rng_continuous(nrng = draws$nsamples, dist = "weibull", args = args, 
+                 lb = draws$data$lb[i], ub = draws$data$ub[i])
 }
 
 predict_inverse.gaussian <- function(i, draws, ...) {
-  args <- list(mean = ilink(get_eta(i, draws), draws$f$link), 
-               shape = draws$shape)
-  rng_continuous(nrng = draws$nsamples, dist = "invgauss",
-                 args = args, data = draws$data)
+  args <- list(mean = ilink(get_eta(draws, i), draws$f$link), 
+               shape = get_shape(draws$shape, data = draws$data, i = i))
+  rng_continuous(nrng = draws$nsamples, dist = "invgauss", args = args, 
+                 lb = draws$data$lb[i], ub = draws$data$ub[i])
 }
 
 predict_beta <- function(i, draws, ...) {
-  mu <- ilink(get_eta(i, draws), draws$f$link)
-  args <- list(shape1 = mu * draws$phi, shape2 = (1 - mu) * draws$phi)
-  rng_continuous(nrng = draws$nsamples, dist = "beta",
-                 args = args, data = draws$data)
+  mu <- ilink(get_eta(draws, i), draws$f$link)
+  phi <- get_auxpar(draws$phi, i = i)
+  args <- list(shape1 = mu * phi, shape2 = (1 - mu) * phi)
+  rng_continuous(nrng = draws$nsamples, dist = "beta", args = args, 
+                 lb = draws$data$lb[i], ub = draws$data$ub[i])
+}
+
+predict_von_mises <- function(i, draws, ...) {
+  args <- list(mu = ilink(get_eta(draws, i), draws$f$link), 
+               kappa = get_auxpar(draws$kappa, i = i))
+  rng_continuous(nrng = draws$nsamples, dist = "von_mises", args = args,
+                 lb = draws$data$lb[i], ub = draws$data$ub[i])
 }
 
 predict_hurdle_poisson <- function(i, draws, ...) {
-  # theta is the bernoulii hurdle parameter
-  theta <- ilink(get_eta(i + draws$data$N_trait, draws), "logit")
-  lambda <- ilink(get_eta(i, draws), draws$f$link)
+  # theta is the bernoulli hurdle parameter
+  theta <- get_theta(draws, i, par = "hu")
+  lambda <- ilink(get_eta(draws, i), draws$f$link)
   ndraws <- draws$nsamples
   # compare with theta to incorporate the hurdle process
   hu <- runif(ndraws, 0, 1)
@@ -248,44 +266,45 @@ predict_hurdle_poisson <- function(i, draws, ...) {
 }
 
 predict_hurdle_negbinomial <- function(i, draws, ...) {
-  # theta is the bernoulii hurdle parameter
-  theta <- ilink(get_eta(i + draws$data$N_trait, draws), "logit")
-  mu <- ilink(get_eta(i, draws), draws$f$link)
+  # theta is the bernoulli hurdle parameter
+  theta <- get_theta(draws, i, par = "hu")
+  mu <- ilink(get_eta(draws, i), draws$f$link)
   ndraws <- draws$nsamples
   # compare with theta to incorporate the hurdle process
   hu <- runif(ndraws, 0, 1)
   # sample from an approximative(!) truncated negbinomial distribution
   # by adjusting mu and adding 1
   t = -log(1 - runif(ndraws) * (1 - exp(-mu)))
-  ifelse(hu < theta, 0, rnbinom(ndraws, mu = mu - t, size = draws$shape) + 1)
+  shape <- get_shape(draws$shape, data = draws$data, i = i)
+  ifelse(hu < theta, 0, rnbinom(ndraws, mu = mu - t, size = shape) + 1)
 }
 
 predict_hurdle_gamma <- function(i, draws, ...) {
-  # theta is the bernoulii hurdle parameter
-  theta <- ilink(get_eta(i + draws$data$N_trait, draws), "logit")
-  scale <- ilink(get_eta(i, draws), draws$f$link) / draws$shape
+  # theta is the bernoulli hurdle parameter
+  theta <- get_theta(draws, i, par = "hu")
+  shape <- get_shape(draws$shape, data = draws$data, i = i)
+  scale <- ilink(get_eta(draws, i), draws$f$link) / shape
   ndraws <- draws$nsamples
   # compare with theta to incorporate the hurdle process
   hu <- runif(ndraws, 0, 1)
-  ifelse(hu < theta, 0, rgamma(ndraws, shape = draws$shape, scale = scale))
+  ifelse(hu < theta, 0, rgamma(ndraws, shape = shape, scale = scale))
 }
 
 predict_zero_inflated_beta <- function(i, draws, ...) {
-  # theta is the bernoulii hurdle parameter
-  theta <- ilink(get_eta(i + draws$data$N_trait, draws), "logit")
-  mu <- ilink(get_eta(i, draws), draws$f$link)
-  shape1 <- mu * draws$phi
-  shape2 <- (1 - mu) * draws$phi
-  ndraws <- draws$nsamples
+  # theta is the bernoulli hurdle parameter
+  theta <- get_theta(draws, i, par = "zi")
+  mu <- ilink(get_eta(draws, i), draws$f$link)
+  phi <- get_auxpar(draws$phi, i = i)
   # compare with theta to incorporate the hurdle process
-  hu <- runif(ndraws, 0, 1)
-  ifelse(hu < theta, 0, rbeta(ndraws, shape1 = shape1, shape2 = shape2))
+  hu <- runif(draws$nsamples, 0, 1)
+  ifelse(hu < theta, 0, rbeta(draws$nsamples, shape1 = mu * phi, 
+                              shape2 = (1 - mu) * phi))
 }
 
 predict_zero_inflated_poisson <- function(i, draws, ...) {
-  # theta is the bernoulii zero-inflation parameter
-  theta <- ilink(get_eta(i + draws$data$N_trait, draws), "logit")
-  lambda <- ilink(get_eta(i, draws), draws$f$link)
+  # theta is the bernoulli zero-inflation parameter
+  theta <- get_theta(draws, i, par = "zi")
+  lambda <- ilink(get_eta(draws, i), draws$f$link)
   ndraws <- draws$nsamples
   # compare with theta to incorporate the zero-inflation process
   zi <- runif(ndraws, 0, 1)
@@ -293,21 +312,22 @@ predict_zero_inflated_poisson <- function(i, draws, ...) {
 }
 
 predict_zero_inflated_negbinomial <- function(i, draws, ...) {
-  # theta is the bernoulii zero-inflation parameter
-  theta <- ilink(get_eta(i + draws$data$N_trait, draws), "logit")
-  mu <- ilink(get_eta(i, draws), draws$f$link)
+  # theta is the bernoulli zero-inflation parameter
+  theta <- get_theta(draws, i, par = "zi")
+  mu <- ilink(get_eta(draws, i), draws$f$link)
+  shape <- get_shape(draws$shape, data = draws$data, i = i)
   ndraws <- draws$nsamples
   # compare with theta to incorporate the zero-inflation process
   zi <- runif(ndraws, 0, 1)
-  ifelse(zi < theta, 0, rnbinom(ndraws, mu = mu, size = draws$shape))
+  ifelse(zi < theta, 0, rnbinom(ndraws, mu = mu, size = shape))
 }
 
 predict_zero_inflated_binomial <- function(i, draws, ...) {
   # theta is the bernoulii zero-inflation parameter
-  theta <- ilink(get_eta(i + draws$data$N_trait, draws), "logit")
+  theta <- get_theta(draws, i, par = "zi")
   trials <- ifelse(length(draws$data$max_obs) > 1, 
                    draws$data$max_obs[i], draws$data$max_obs)
-  prob <- ilink(get_eta(i, draws), draws$f$link)
+  prob <- ilink(get_eta(draws, i), draws$f$link)
   ndraws <- draws$nsamples
   # compare with theta to incorporate the zero-inflation process
   zi <- runif(ndraws, 0, 1)
@@ -317,7 +337,7 @@ predict_zero_inflated_binomial <- function(i, draws, ...) {
 predict_categorical <- function(i, draws, ...) {
   ncat <- ifelse(length(draws$data$max_obs) > 1, 
                  draws$data$max_obs[i], draws$data$max_obs) 
-  p <- pcategorical(1:ncat, eta = get_eta(i, draws, ordinal = TRUE)[, 1, ], 
+  p <- pcategorical(1:ncat, eta = get_eta(draws, i)[, 1, ], 
                     ncat = ncat, link = draws$f$link)
   first_greater(p, target = runif(draws$nsamples, min = 0, max = 1))
 }
@@ -341,35 +361,34 @@ predict_acat <- function(i, draws, ...) {
 predict_ordinal <- function(i, draws, family, ...) {
   ncat <- ifelse(length(draws$data$max_obs) > 1, 
                  draws$data$max_obs[i], draws$data$max_obs)
-  p <- pordinal(1:ncat, eta = get_eta(i, draws, ordinal = TRUE)[, 1, ], 
+  p <- pordinal(1:ncat, eta = get_eta(draws, i)[, 1, ], 
                 ncat = ncat, family = family, link = draws$f$link)
   first_greater(p, target = runif(draws$nsamples, min = 0, max = 1))
 }
 
 #---------------predict helper-functions----------------------------
 
-rng_continuous <- function(nrng, dist, args, data) {
+rng_continuous <- function(nrng, dist, args, lb = NULL, ub = NULL) {
   # random numbers from (possibly truncated) continuous distributions
   # Args:
   #   nrng: number of random values to generate
   #   dist: name of a distribution for which the functions
   #         p<dist>, q<dist>, and r<dist> are available
   #   args: dditional arguments passed to the distribution functions
-  #   data: data initially passed to Stan
   # Returns:
   #   a vector of random values draws from the distribution
-  if (is.null(data$lb) && is.null(data$ub)) {
+  if (is.null(lb) && is.null(ub)) {
     # sample as usual
-    rdist <- paste0("r",dist)
+    rdist <- paste0("r", dist)
     out <- do.call(rdist, c(nrng, args))
   } else {
     # sample from truncated distribution
-    lb <- ifelse(is.null(data$lb), -Inf, data$lb)
-    ub <- ifelse(is.null(data$ub), Inf, data$ub)
-    pdist <- paste0("p",dist)
-    qdist <- paste0("q",dist)
-    plb <- do.call(pdist, c(lb, args))
-    pub <- do.call(pdist, c(ub, args))
+    if (is.null(lb)) lb <- -Inf
+    if (is.null(ub)) ub <- Inf
+    pdist <- paste0("p", dist)
+    qdist <- paste0("q", dist)
+    plb <- do.call(pdist, c(list(lb), args))
+    pub <- do.call(pdist, c(list(ub), args))
     rng <- list(runif(nrng, min = plb, max = pub))
     out <- do.call(qdist, c(rng, args))
     # remove infinte values caused by numerical imprecision
@@ -378,7 +397,7 @@ rng_continuous <- function(nrng, dist, args, data) {
   out
 }
 
-rng_discrete <- function(nrng, dist, args, data, ntrys) {
+rng_discrete <- function(nrng, dist, args, lb = NULL, ub = NULL, ntrys = 5) {
   # random numbers from (possibly truncated) discrete distributions
   # currently rejection sampling is used for truncated distributions
   # Args:
@@ -386,18 +405,19 @@ rng_discrete <- function(nrng, dist, args, data, ntrys) {
   #   dist: name of a distribution for which the functions
   #         p<dist>, q<dist>, and r<dist> are available
   #   args: dditional arguments passed to the distribution functions
-  #   data: data initially passed to Stan
-  #   number of trys in rejection sampling for truncated models
+  #   lb: optional lower truncation bound
+  #   ub: optional upper truncation bound
+  #   ntrys: number of trys in rejection sampling for truncated models
   # Returns:
   #   a vector of random values draws from the distribution
-  rdist <- get(paste0("r",dist), mode = "function")
-  if (is.null(data$lb) && is.null(data$ub)) {
+  rdist <- get(paste0("r", dist), mode = "function")
+  if (is.null(lb) && is.null(ub)) {
     # sample as usual
     do.call(rdist, c(nrng, args))
   } else {
     # sample from truncated distribution via rejection sampling
-    lb <- ifelse(is.null(data$lb), -Inf, data$lb)
-    ub <- ifelse(is.null(data$ub), Inf, data$ub)
+    if (is.null(lb)) lb <- -Inf
+    if (is.null(ub)) ub <- Inf
     rng <- matrix(do.call(rdist, c(nrng * ntrys, args)), ncol = ntrys)
     apply(rng, 1, extract_valid_sample, lb = lb, ub = ub)
   }
@@ -423,16 +443,18 @@ extract_valid_sample <- function(rng, lb, ub) {
   }
 }
 
-get_pct_invalid <- function(x, data) {
+get_pct_invalid <- function(x, lb = NULL, ub = NULL) {
   # percentage of invalid predictions of truncated discrete models
   # Args:
   #   x: matrix of predicted values
-  #   data: data initially passed to Stan
-  if (!(is.null(data$lb) && is.null(data$ub))) {
-    lb <- ifelse(is.null(data$lb), -Inf, data$lb)
-    ub <- ifelse(is.null(data$ub), Inf, data$ub)
-    x <- c(x)[!is.na(c(x))]
-    sum(x < (lb + 1) | x > ub) / length(x) 
+  #   lb: optional lower truncation bound
+  #   ub: optional upper truncation bound
+  if (!(is.null(lb) && is.null(ub))) {
+    if (is.null(lb)) lb <- -Inf
+    if (is.null(ub)) ub <- Inf
+    # ensures correct comparison with vector bounds
+    x <- c(t(x))
+    sum(x <= lb | x > ub, na.rm = TRUE) / length(x[!is.na(x)]) 
   } else {
     0
   }
