@@ -86,7 +86,7 @@ rename_pars <- function(x) {
   class[pos_intercept] <- "b_Intercept"
   ordered <- order(factor(class, levels = all_classes))
   x$fit@sim$fnames_oi <- x$fit@sim$fnames_oi[ordered]
-  for (i in 1:chains) {
+  for (i in seq_len(chains)) {
     # subset_attr ensures that attributes are not removed
     x$fit@sim$samples[[i]] <- subset_attr(x$fit@sim$samples[[i]], ordered)
   }
@@ -115,20 +115,21 @@ rename_pars <- function(x) {
     resp <- ee$response
     if (length(resp) > 1L) {
       for (r in resp) {
+        fixef <- rm_int_fixef(colnames(standata[[paste0("X_", r)]]), 
+                              stancode(x), nlpar = r)
         change_eff <- change_effects(
-          pars = pars, dims = x$fit@sim$dims_oi,
-          fixef = colnames(standata[[paste0("X_", r)]]), 
-          monef = colnames(standata[[paste0("Xm_", r)]]),
+          pars = pars, dims = x$fit@sim$dims_oi, 
+          fixef = fixef, monef = colnames(standata[[paste0("Xm_", r)]]),
           splines = get_spline_labels(ee), nlpar = r)
         change <- c(change, change_eff)
       }
     } else {
+      fixef <- rm_int_fixef(colnames(standata[["X"]]), stancode(x))
       change_eff <- change_effects(
-        pars = pars, dims = x$fit@sim$dims_oi,
-        fixef = colnames(standata$X), 
-        monef = colnames(standata$Xm),
+        pars = pars, dims = x$fit@sim$dims_oi, 
+        fixef = fixef, monef = colnames(standata[["Xm"]]),
         splines = get_spline_labels(ee))
-      change_csef <- change_csef(colnames(standata$Xp), 
+      change_csef <- change_csef(colnames(standata[["Xp"]]), 
                                  pars = pars, ncat = standata$ncat)
       change <- c(change, change_eff, change_csef)
     }
@@ -191,10 +192,12 @@ change_fixef <- function(fixef, pars, nlpar = "") {
   change <- list()
   if (length(fixef)) {
     b <- paste0("b", usc(nlpar, "prefix"))
-    change <- lc(change, list(pos = grepl(paste0("^", b, "\\["), pars), 
-                              oldname = b, pnames = paste0(b, "_", fixef), 
-                              fnames = paste0(b, "_", fixef)))
-    change <- c(change, change_prior(class = b, pars = pars, names = fixef))
+    pos <- grepl(paste0("^", b, "\\["), pars)
+    bnames <- paste0(b, "_", fixef)
+    change <- lc(change, 
+      list(pos = pos, oldname = b, pnames = bnames, fnames = bnames))
+    change <- c(change,
+      change_prior(class = b, pars = pars, names = fixef))
   }
   change
 }
@@ -526,6 +529,16 @@ change_simple <- function(oldname, fnames, pars, dims,
   return(out)
 }
 
+rm_int_fixef <- function(fixef, stancode, nlpar = "") {
+  # identifies if the intercept has to be removed from fixef
+  # and returns adjusted fixef names
+  regex <- paste0("int Kc", usc(nlpar), ";")
+  if (grepl(regex, stancode, fixed = TRUE)) {
+    fixef <- setdiff(fixef, "Intercept")
+  } 
+  fixef
+}
+
 make_index_names <- function(rownames, colnames = NULL, dim = 1) {
   # compute index names in square brackets for indexing stan parameters
   # Args:
