@@ -1,7 +1,10 @@
 test_that("fitted helper functions run without errors", {
   # actually run fitted.brmsfit that call the helper functions
-  fit <- brms:::rename_pars(brmsfit_example)
+  fit <- brms:::rename_pars(brmsfit_example1)
   fit <- brms:::add_samples(fit, "shape", dist = "exp")
+  # nu must come after hu here to avoid a strange error in rstan
+  fit <- brms:::add_samples(fit, "hu", dist = "beta", shape1 = 1, shape2 = 1)
+  fit <- brms:::add_samples(fit, "zi", dist = "beta", shape1 = 1, shape2 = 1)
   fit <- brms:::add_samples(fit, "nu", dist = "exp")
   draws <- brms:::extract_draws(fit)
   eta <- brms:::linear_predictor(draws)
@@ -16,6 +19,7 @@ test_that("fitted helper functions run without errors", {
   fit$family <- gaussian("log")
   expect_equal(dim(fitted(fit, summary = FALSE)), c(nsamples, nobs))
   # pseudo weibull model
+  fit$formula <- rm_attr(fit$formula, "sigma")
   fit$family <- weibull()
   expect_equal(dim(SW(fitted(fit, summary = FALSE))), c(nsamples, nobs))
   # pseudo binomial model
@@ -23,7 +27,6 @@ test_that("fitted helper functions run without errors", {
   fit$family <- binomial()
   expect_equal(dim(fitted(fit, summary = FALSE)), c(nsamples, nobs))
   # pseudo hurdle poisson model
-  names(fit$data)[1] <- "response"
   fit$family <- hurdle_poisson()
   fit$formula <- count ~ Trt*Age + mono(Exp) + offset(Age) + (1+Trt|visit)
   expect_equal(dim(fitted(fit, summary = FALSE)), c(nsamples, nobs(fit)))
@@ -52,14 +55,17 @@ test_that("fitted helper functions run without errors", {
   expect_equal(dim(mu), c(nsamples, nobs))
   # truncated discrete models
   data <- list(Y = sample(100, 10), trials = 1:10, N = 10)
-  mu <- fitted_trunc_poisson(exp_eta, lb = 0, ub = 100, draws = draws)
+  lb <- matrix(0, nrow = nsamples, ncol = nobs)
+  ub <- matrix(100, nrow = nsamples, ncol = nobs)
+  mu <- fitted_trunc_poisson(exp_eta, lb = lb, ub = ub, draws = draws)
   expect_equal(dim(mu), c(nsamples, nobs))
-  mu <- fitted_trunc_negbinomial(exp_eta, lb = 0, ub = 100, draws = draws)
+  mu <- fitted_trunc_negbinomial(exp_eta, lb = lb, ub = ub,draws = draws)
   expect_equal(dim(mu), c(nsamples, nobs))
-  mu <- fitted_trunc_geometric(exp_eta, lb = 0, ub = 100, draws = draws)
+  mu <- fitted_trunc_geometric(exp_eta, lb = lb, ub = ub, draws = draws)
   expect_equal(dim(mu), c(nsamples, nobs))
   draws$data$trials <- 120
-  mu <- fitted_trunc_binomial(ilink(eta, "logit"), lb = -Inf, ub = 100, 
+  lb <- matrix(-Inf, nrow = nsamples, ncol = nobs)
+  mu <- fitted_trunc_binomial(ilink(eta, "logit"), lb = lb, ub = ub,
                               draws = draws)
   expect_equal(dim(mu), c(nsamples, nobs))
 })
\ No newline at end of file
